package com.example.smartledz_wifi_test;

import android.Manifest;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.pm.PackageManager;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.net.wifi.ScanResult;
import android.net.wifi.WifiManager;
import android.os.Build;
import android.os.Bundle;
import android.widget.ArrayAdapter;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;

import com.example.smartledz_wifi_test.plugin.EventChannelPlugin;
import com.example.smartledz_wifi_test.plugin.WifiPlugin;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.flutter.embedding.android.FlutterActivity;
import io.flutter.embedding.engine.FlutterEngine;
import io.flutter.plugins.GeneratedPluginRegistrant;

public class MainActivity extends FlutterActivity {


    public static WifiManager wifiManager;
    public static ConnectivityManager connectivityManager;

    private static final int PERMISSIONS_REQUEST_CODE = 1;
    private BroadcastReceiver wifiScanReceiver;

    private BroadcastReceiver netWorkChangeReceiver;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        wifiManager = (WifiManager) getApplicationContext().getSystemService(Context.WIFI_SERVICE);
        connectivityManager = (ConnectivityManager) getApplicationContext().getSystemService(Context.CONNECTIVITY_SERVICE);
        // 检查并请求定位权限
        checkAndRequestPermissions();
        // 注册Wi-Fi扫描广播接收器
        registerWifiScanReceiver();
        registerNetWorkChangeReceiver();
        // 检查并启用Wi-Fi
        if (!wifiManager.isWifiEnabled()) {
            wifiManager.setWifiEnabled(true);
        }
        super.onCreate(savedInstanceState);
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        unregisterReceiver(wifiScanReceiver);
        unregisterReceiver(netWorkChangeReceiver);
    }

    @Override
    public void configureFlutterEngine(@NonNull FlutterEngine flutterEngine) {
        //插件实例的注册...
        // telink-sdk插件
        flutterEngine.getPlugins().add(new WifiPlugin());
        // 通知插件
        flutterEngine.getPlugins().add(EventChannelPlugin.getInstance());
        //这个是必写，别删除！！
        GeneratedPluginRegistrant.registerWith(flutterEngine);
    }

    private void scanWifiList() {
        List<ScanResult> scanResults = wifiManager.getScanResults();
//        System.out.println("获取扫描列表");
//        System.out.println(scanResults);
//        System.out.println("-----------------------------");
//        List<Map<String,String>> wifiList = new ArrayList<>();
        JSONObject response = new JSONObject();
        for (ScanResult scanResult : scanResults) {
             if(!scanResult.SSID.equals("endo-lighting")){
                 continue;
             }
            try {
                response.put("cmd","scanResult");
                response.put("ssid",scanResult.SSID);
                response.put("bssid",scanResult.BSSID);
                response.put("level",String.valueOf(scanResult.level));
            } catch (JSONException e) {
                throw new RuntimeException(e);
            }
            EventChannelPlugin.getInstance().sendEventData(response.toString());
        }
        response = new JSONObject();
        try {
            response.put("cmd","scanComplete");
        } catch (JSONException e) {
            throw new RuntimeException(e);
        }
        EventChannelPlugin.getInstance().sendEventData(response.toString());

    }

    private void checkAndRequestPermissions() {
        int permissionCheck = ContextCompat.checkSelfPermission(this, Manifest.permission.ACCESS_FINE_LOCATION);
        if (permissionCheck != PackageManager.PERMISSION_GRANTED) {
            ActivityCompat.requestPermissions(this, new String[]{Manifest.permission.ACCESS_FINE_LOCATION}, PERMISSIONS_REQUEST_CODE);
        }
    }

    private void registerWifiScanReceiver() {
        wifiScanReceiver = new BroadcastReceiver() {
            @Override
            public void onReceive(Context context, Intent intent) {
                if (intent.getAction().equals(WifiManager.SCAN_RESULTS_AVAILABLE_ACTION)) {
                    scanWifiList();
                }
            }
        };
        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction(WifiManager.SCAN_RESULTS_AVAILABLE_ACTION);
        registerReceiver(wifiScanReceiver, intentFilter);
    }

    private void registerNetWorkChangeReceiver(){
        netWorkChangeReceiver = new BroadcastReceiver() {
            @Override
            public void onReceive(Context context, Intent intent) {
                if (intent.getAction().equals(WifiManager.NETWORK_STATE_CHANGED_ACTION)) {
                    NetworkInfo networkInfo = intent.getParcelableExtra(WifiManager.EXTRA_NETWORK_INFO);
                    if (networkInfo != null && networkInfo.isConnected()) {
                        if(networkInfo.isConnected()){
                            System.out.println("wifi成功连接");
                            // Wi-Fi连接成功
                            JSONObject response = new JSONObject();
                            try {
                                response.put("cmd","connected");
                            } catch (JSONException e) {
                                throw new RuntimeException(e);
                            }
                            EventChannelPlugin.getInstance().sendEventData(response.toString());
                        } else if (!networkInfo.isConnected()) {
                            System.out.println("wifi断开");
                            // Wi-Fi连接成功
                            JSONObject response = new JSONObject();
                            try {
                                response.put("cmd","disconnect");
                            } catch (JSONException e) {
                                throw new RuntimeException(e);
                            }
                            EventChannelPlugin.getInstance().sendEventData(response.toString());
                        }
                    }
                }
            }
        };
        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction(WifiManager.NETWORK_STATE_CHANGED_ACTION);
        registerReceiver(netWorkChangeReceiver, intentFilter);
    }

}
