package com.example.smartledz_wifi_test.plugin;


import android.net.ConnectivityManager;
import android.net.MacAddress;
import android.net.Network;
import android.net.NetworkCapabilities;
import android.net.NetworkRequest;
import android.net.wifi.WifiConfiguration;
import android.net.wifi.WifiNetworkSpecifier;
import android.net.wifi.WifiNetworkSuggestion;
import android.os.Build;

import androidx.annotation.NonNull;
import androidx.annotation.RequiresApi;


import com.example.smartledz_wifi_test.MainActivity;

import java.util.ArrayList;
import java.util.List;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodChannel;

public class WifiPlugin implements FlutterPlugin {

    // 插件名称
    public static final String channelName = "com.vanstone.WifiPlugin";

    private static final int PERMISSIONS_REQUEST_CODE = 101;


    @Override
    public void onAttachedToEngine(@NonNull FlutterPlugin.FlutterPluginBinding binding) {
        //可以利用binding对象获取到Android中需要的Context对象
//        Context applicationContext = binding.getApplicationContext();


        //设置channel名称，之后flutter中也要一样
        MethodChannel channel = new MethodChannel(binding.getFlutterEngine().getDartExecutor(), channelName);

        //把当前的MethodCallHandler设置
        channel.setMethodCallHandler((call, result) -> {
            String method = call.method;
            switch (method) {
                case "startScan":
                    startScan();
//                    System.out.println("-------------------");
//                    System.out.println(scanResults);
//                    System.out.println("-------------------");
                    break;
                case "connect":
                    String ssid = call.argument("ssid");
                    String bssid = call.argument("bssid");
                    String password = call.argument("password");
                    connect(ssid, bssid, password);
//                    result.success(connect(mac));
                    break;
                case "disconnect":
                    disconnect();
                    break;
            }
        });
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {

    }


    private void startScan() {
        MainActivity.wifiManager.startScan(); // 触发Wi-Fi扫描
    }

    // 连接wifi
    private void connect(String ssid, String bssid, String pwd) {

//        System.out.printf("ssid  = %s",ssid);
//        System.out.printf("pwd  = %s",pwd);
//        WifiConfiguration wifiConfig = new WifiConfiguration();
//        wifiConfig.SSID = "\"" + ssid + "\"";
////        wifiConfig.BSSID = bssid;
//        wifiConfig.preSharedKey = "\"" + pwd + "\"";
//        int networkId = MainActivity.wifiManager.addNetwork(wifiConfig);
//        MainActivity.wifiManager.disconnect();
//        boolean b = MainActivity.wifiManager.enableNetwork(networkId, true);
//        System.out.println("连接结果");
//        System.out.println(b);
//        MainActivity.wifiManager.reconnect();
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.Q) {
            connectByNewVer(ssid, bssid, pwd);
        } else {
            connectByOldVer(ssid, bssid, pwd);
        }
    }

    private void disconnect(){
        int networkId = MainActivity.wifiManager.getConnectionInfo().getNetworkId();
        // 断开当前的 Wi-Fi 连接
        MainActivity.wifiManager.disableNetwork(networkId);
        MainActivity.wifiManager.disconnect();
    }

    /**
     * Android 10 以上使用
     *
     **/
    @RequiresApi(api = Build.VERSION_CODES.Q)
    private void connectByNewVer(String ssid, String bssid, String pwd) {
        WifiNetworkSpecifier wifiNetworkSpecifier = new WifiNetworkSpecifier.Builder()
                .setSsid(ssid)
                .setBssid(MacAddress.fromString(bssid))
                .setWpa2Passphrase(pwd)
                .build();
        NetworkRequest networkRequest = new NetworkRequest.Builder()
                .addTransportType(NetworkCapabilities.TRANSPORT_WIFI)
                .setNetworkSpecifier(wifiNetworkSpecifier)
                .build();
            // step3-连接wifi
        MainActivity.connectivityManager.requestNetwork(networkRequest, new ConnectivityManager.NetworkCallback());
    }

    /**
    * Android 10 以下使用
    *
    **/
    private void connectByOldVer(String ssid, String bssid, String pwd){
        WifiConfiguration config = new WifiConfiguration();
        config.SSID = "\"" + ssid + "\"";
//        config.BSSID = bssid;
        config.preSharedKey = "\"" + pwd + "\"";
        config.hiddenSSID = true;
        config.allowedAuthAlgorithms.set(WifiConfiguration.AuthAlgorithm.OPEN);
        config.allowedGroupCiphers.set(WifiConfiguration.GroupCipher.TKIP);
        config.allowedKeyManagement.set(WifiConfiguration.KeyMgmt.WPA_PSK);
        config.allowedPairwiseCiphers.set(WifiConfiguration.PairwiseCipher.TKIP);
        config.allowedGroupCiphers.set(WifiConfiguration.GroupCipher.CCMP);
        config.allowedPairwiseCiphers.set(WifiConfiguration.PairwiseCipher.CCMP);
        config.status = WifiConfiguration.Status.ENABLED;
        int netId =  MainActivity.wifiManager.addNetwork(config);
        MainActivity.wifiManager.disconnect();
        boolean isSuccess = MainActivity.wifiManager.enableNetwork(netId, true);
        System.out.println("Android 10 以下连接 ----> ");
        System.out.println(isSuccess);
    }

}
